package com.evobms.project.battery.service;

import java.util.List;
import com.evobms.project.battery.domain.ExtremeValues;

/**
 * 电池极值数据Service接口
 *
 * @author 田志阳
 * @date 2025-10-14
 */
public interface IExtremeValuesService
{
    /**
     * 查询电池极值数据
     *
     * @param id 电池极值数据主键
     * @return 电池极值数据
     */
    public ExtremeValues selectExtremeValuesById(Long id);

    /**
     * 查询电池极值数据列表
     *
     * @param extremeValues 电池极值数据
     * @return 电池极值数据集合
     */
    public List<ExtremeValues> selectExtremeValuesList(ExtremeValues extremeValues);

    /**
     * 新增电池极值数据
     *
     * @param extremeValues 电池极值数据
     * @return 结果
     */
    public int insertExtremeValues(ExtremeValues extremeValues);

    /**
     * 修改电池极值数据
     *
     * @param extremeValues 电池极值数据
     * @return 结果
     */
    public int updateExtremeValues(ExtremeValues extremeValues);

    /**
     * 批量删除电池极值数据
     *
     * @param ids 需要删除的电池极值数据主键集合
     * @return 结果
     */
    public int deleteExtremeValuesByIds(Long[] ids);

    /**
     * 删除电池极值数据信息
     *
     * @param id 电池极值数据主键
     * @return 结果
     */
    public int deleteExtremeValuesById(Long id);

    ExtremeValues selectLatestByDeviceId(String deviceId);

    ExtremeValues selectLatestByDeviceIdBefore(String deviceId, java.util.Date beforeTime);
}
